@@ -8,7 +8,7 @@ from dbt_cloud.command import (
     DbtCloudJobCreateCommand,
     DbtCloudJobDeleteCommand,
     DbtCloudJobRunCommand,
-    DbtCloudCommand,
+    DbtCloudAccountCommand,
     DbtCloudRunGetCommand,
     DbtCloudRunListArtifactsCommand,
     DbtCloudRunGetArtifactCommand,
@@ -18,6 +18,7 @@ from dbt_cloud.command import (
     DbtCloudJobListCommand,
     DbtCloudProjectListCommand,
     DbtCloudEnvironmentListCommand,
+    DbtCloudAccountListCommand,
 )
 from dbt_cloud.demo import data_catalog
 from dbt_cloud.serde import json_to_dict, dict_to_json
@@ -32,7 +33,7 @@ def execute_and_print(command, **kwargs):
     return response
 
 
-@click.group()
+@click.group(help="The dbt Cloud command line interface.")
 def dbt_cloud():
     import http.client as http_client
 
@@ -45,27 +46,32 @@ def dbt_cloud():
         http_client.HTTPConnection.debuglevel = 1
 
 
-@dbt_cloud.group(help="dbt Cloud job commands")
+@dbt_cloud.group(help="Interact with dbt Cloud jobs.")
 def job():
     pass
 
 
-@dbt_cloud.group(name="run", help="dbt Cloud run commands")
+@dbt_cloud.group(name="run", help="Interact with dbt Cloud job runs.")
 def job_run():
     pass
 
 
-@dbt_cloud.group(help="dbt Cloud project commands")
+@dbt_cloud.group(help="Interact with dbt Cloud projects.")
 def project():
     pass
 
 
-@dbt_cloud.group(help="dbt Cloud environment commands")
+@dbt_cloud.group(help="Interact with dbt Cloud environments.")
 def environment():
     pass
 
 
-@dbt_cloud.group(help="dbt Cloud Metadata API commands")
+@dbt_cloud.group(help="Interact with dbt Cloud accounts.")
+def account():
+    pass
+
+
+@dbt_cloud.group(help="Interact with the dbt Cloud Metadata API.")
 def metadata():
     pass
 
@@ -204,7 +210,7 @@ def export(file, **kwargs):
 
 
 @job.command(help="Imports a dbt Cloud job from exported JSON.", name="import")
-@DbtCloudCommand.click_options
+@DbtCloudAccountCommand.click_options
 @click.option(
     "-f",
     "--file",
@@ -213,7 +219,7 @@ def export(file, **kwargs):
     help="Import file path.",
 )
 def import_job(file, **kwargs):
-    base_command = DbtCloudCommand.from_click_options(**kwargs)
+    base_command = DbtCloudAccountCommand.from_click_options(**kwargs)
     job_create_kwargs = {**json_to_dict(file.read()), **base_command.dict()}
     command = DbtCloudJobCreateCommand(**job_create_kwargs)
     response = command.execute()
@@ -228,6 +234,41 @@ def cancel(**kwargs):
     execute_and_print(command)
 
 
+@job_run.command(help="Cancel all running jobs by status.")
+@DbtCloudRunListCommand.click_options
+@click.option("--dry-run", is_flag=True, help="Execute as a dry run.")
+@click.option(
+    "-y", "--yes", "assume_yes", is_flag=True, help="Automatic yes to prompts."
+)
+@click.option(
+    "-f",
+    "--file",
+    default="-",
+    type=click.File("w"),
+    help="Response export file path.",
+)
+def cancel_all(dry_run, file, assume_yes, **kwargs):
+    list_command = DbtCloudRunListCommand.from_click_options(**kwargs)
+    response = list_command.execute()
+    response.raise_for_status()
+    run_ids_to_cancel = [run_dict["id"] for run_dict in response.json()["data"]]
+    click.echo(f"Runs to cancel: {run_ids_to_cancel}")
+    cancelled_job_responses = []
+    if not dry_run:
+        for run_id in run_ids_to_cancel:
+            cancel_command = DbtCloudRunCancelCommand(**kwargs, run_id=run_id)
+            if assume_yes:
+                is_confirmed = True
+            else:
+                is_confirmed = click.confirm(f"Cancel run {run_id}?")
+            if is_confirmed:
+                response = cancel_command.execute()
+                response.raise_for_status()
+                cancelled_job_responses.append(response.json())
+                click.echo(f"Run {run_id} has been cancelled.")
+    file.write(dict_to_json(cancelled_job_responses))
+
+
 @job_run.command(help=DbtCloudRunGetCommand.get_description())
 @DbtCloudRunGetCommand.click_options
 def get(**kwargs):
@@ -284,6 +325,13 @@ def list(**kwargs):
     response = execute_and_print(command)
 
 
+@account.command(help=DbtCloudAccountListCommand.get_description())
+@DbtCloudAccountListCommand.click_options
+def list(**kwargs):
+    command = DbtCloudAccountListCommand.from_click_options(**kwargs)
+    response = execute_and_print(command)
+
+
 @metadata.command(help=DbtCloudMetadataQueryCommand.get_description())
 @click.option(
     "-f",
