@@ -14,6 +14,7 @@ from dbt_cloud.command import (
     DbtCloudRunListArtifactsCommand,
     DbtCloudRunListCommand,
     DbtCloudEnvironmentListCommand,
+    DbtCloudAccountListCommand,
 )
 
 
@@ -146,6 +147,13 @@ COMMAND_TEST_CASES = [
         "get",
         marks=pytest.mark.environment,
     ),
+    pytest.param(
+        "account_list",
+        DbtCloudAccountListCommand(api_token=API_TOKEN),
+        load_response("account_list_response"),
+        "get",
+        marks=pytest.mark.account,
+    ),
 ]
 
 
